bbc1.core.compat package
========================

Submodules
----------

.. toctree::

   bbc1.core.compat.bbc_app
   bbc1.core.compat.bbclib

Module contents
---------------

.. automodule:: bbc1.core.compat
    :members:
    :undoc-members:
    :show-inheritance:
